@@ -36,9 +36,9 @@ pub trait Broker: Sized {
     /// Handles the result of each op
     /// 
     /// Returns a `None` to stop the whole loop
-    async fn handle_result(_res: Result<Self::Ok, Self::Error>) -> Running<()> {
-        #[cfg(feature = "debug")]
-        if let Err(err) = _res {
+    async fn handle_result(res: Result<Self::Ok, Self::Error>) -> Running<()> {
+        if let Err(_err) = res {
+            #[cfg(feature = "debug")]
             log::error!("{:?}", _err);
         }
         Running::Continue(())
